Introduction
------------

MERMAKE is a the backend for the MERFISH+ line of spatial transcriptomics.

To install `MERMAKE`,
```
python3 -m pip install mermake
```

or

```sh
 git clone https://github.com/deprekate/MERMAKE.git
 pip install MERMAKE/.
```


MERMAKE Example
--------------
The final full gui interface is currently still in development, but a sample worker script
is included in the github repo. All of the data paths and hyper parameters are hardcoded in
the worker.py script, and will need to be adjusted to fit your environment.  

Some of the variables to set are:
1. psf
2. flat field



